package com.chinaitop.depot.intelligent.basicdata.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.intelligent.basicdata.mapper.TNNtinfoHistoryMapper;
import com.chinaitop.depot.intelligent.basicdata.mapper.TNRoomInfoMapper;
import com.chinaitop.depot.intelligent.basicdata.model.*;
import com.chinaitop.depot.intelligent.basicdata.service.NitrogenService;
import com.chinaitop.depot.intelligent.basicdata.service.WareHouseBasicInfoService;
import com.chinaitop.depot.intelligent.utils.DateUtils;
import com.chinaitop.depot.intelligent.utils.JsonToObjectUtils;
import com.chinaitop.depot.intelligent.utils.UuidUtils;
import com.unissoft.model.BasicEntity;
import com.unissoft.model.SendEntity;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service
public class NitrogenServiceImpl implements NitrogenService {
    @Resource
    private TNRoomInfoMapper tnRoomInfoMapper;

    @Resource
    private TNNtinfoHistoryMapper tNNtinfoHistoryMapper;
    @Resource
    private NitrogenService nitrogenService;
    @Resource
    private WareHouseBasicInfoService wareHouseBasicInfoService;
    @Resource
    private UuidUtils uUidUtils;

    @Override
    public List<TNRoomInfo> getList(String rName) {
        TNRoomInfoExample example = new TNRoomInfoExample();
        TNRoomInfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(rName)) {
            criteria.andNitrogenhouseLike("%"+rName+"%");
        }
        criteria.andDelFlagEqualTo(1);//未删除
        return tnRoomInfoMapper.selectByExample(example);
    }

    @Override
    public TNRoomInfo getById(String id) {
        return tnRoomInfoMapper.selectByPrimaryKey(id);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void save(String grainJson) {
        if (StringUtils.isNotBlank(grainJson)) {
            TNRoomInfo tnRoomInfo = (TNRoomInfo) JsonToObjectUtils.jsonToObject(grainJson, "com.chinaitop.depot.intelligent.basicdata.model.TNRoomInfo");
            tnRoomInfo.setUpdatetime(DateUtils.getDate());
            // 推送基础数据
            JSONObject jsonObject = SendEntity.synchronizationConvert(grainJson);
            // 更新时间
            jsonObject.put("updatetime",DateUtils.dateToString(tnRoomInfo.getUpdatetime()));
            if (StringUtils.isNotBlank(tnRoomInfo.getId())) {
                tnRoomInfoMapper.updateByPrimaryKey(tnRoomInfo);
                // 推送数据并返回结果
                SendEntity.cxfFactor().saveNitrogenData(SendEntity.sendAndConvert(jsonObject, "U"));
            } else {
                // 获取Max+1值
                Map<String, Object> valueMax = wareHouseBasicInfoService.getCode("t_n_room_info", "sitecode", "vdevcode", null);
                // 替换值
                jsonObject.put("vdevcode",valueMax.get("column2"));
                tnRoomInfo.setVdevcode(valueMax.get("column2").toString());
                tnRoomInfo.setId(uUidUtils.getCodeId(tnRoomInfo.getOrgId(), "t_n_room_info"));
                tnRoomInfo.setDelFlag(1); //未删除
                tnRoomInfoMapper.insert(tnRoomInfo);
                // 推送数据并返回结果
                SendEntity.cxfFactor().saveNitrogenData(SendEntity.sendAndConvert(jsonObject, "I"));
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public int deleteById(String id, String basicRoomSetJson) {
        TNRoomInfo tnRoomInfo = (TNRoomInfo) JsonToObjectUtils.jsonToObject(basicRoomSetJson, "com.chinaitop.depot.intelligent.basicdata.model.TNRoomInfo");
        tnRoomInfo.setDelFlag(0); //删除
        int i = tnRoomInfoMapper.updateByPrimaryKeySelective(tnRoomInfo);
        // 推送基础数据
        if (i>0){
            JSONObject jsonObject = SendEntity.synchronizationConvert(basicRoomSetJson);
            SendEntity.cxfFactor().saveNitrogenData(SendEntity.sendAndConvert(jsonObject, "D"));
        }
        return i;
    }

    @Override
    public boolean getBycfCode(String vdevcode, String vdevname) {
        TNRoomInfoExample example = new TNRoomInfoExample();
        TNRoomInfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(vdevcode)) {
            criteria.andVdevcodeEqualTo(vdevcode);
        }
        if (StringUtils.isNotEmpty(vdevname)) {
            criteria.andNitrogenhouseEqualTo(vdevname);
        }
        List<TNRoomInfo> tnRoomInfos = tnRoomInfoMapper.selectByExample(example);
        if (tnRoomInfos.size() > 0) {
            return true;
        }
        return false;
    }

    /**
     * 保存作业记录
     * @param type
     * @param ktinfoJson
     * @param uperson
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void saveHistoryData(String type, String ktinfoJson, String uperson, Integer energy) {
        TKtinfo tKtinfo = (TKtinfo) JsonToObjectUtils.jsonToObject(ktinfoJson, TKtinfo.class);
        TNNtinfoHistory tnNtinfoHistory = new TNNtinfoHistory();

        BigDecimal b = new BigDecimal(energy);
        if ("open".equals(type)) {
            tnNtinfoHistory.setId(UuidUtils.getCode()); // id
            tnNtinfoHistory.setVcfcode(tKtinfo.getVcfcode()); // 仓房code
            tnNtinfoHistory.setVdevcode(tKtinfo.getVdevcode()); // 设备code
            tnNtinfoHistory.setVdevname(tKtinfo.getVdevname()); // 设备名称
            tnNtinfoHistory.setUperson(uperson); // 操作人
            tnNtinfoHistory.setRemark(tKtinfo.getRemark()); // 具体详细信息
            tnNtinfoHistory.setOrgId(tKtinfo.getOrgId()); // 组织机构代码
            tnNtinfoHistory.setStarttime(new Date()); // 开始时间
            tnNtinfoHistory.setEnergy(b); //区分是氮气气调还是氮气房
            tNNtinfoHistoryMapper.insertSelective(tnNtinfoHistory); // 新增作业记录
            nitrogenService.save(ktinfoJson); // 更新操作状态
        } else if ("close".equals(type)){
            TNNtinfoHistoryExample example = new TNNtinfoHistoryExample();
            TNNtinfoHistoryExample.Criteria criteria = example.createCriteria();
            criteria.andOrgIdEqualTo(tKtinfo.getOrgId());
            criteria.andVcfcodeEqualTo(tKtinfo.getVcfcode());
            criteria.andVdevcodeEqualTo(tKtinfo.getVdevcode());
            criteria.andVdevnameEqualTo(tKtinfo.getVdevname());
            criteria.andEndtimeIsNull();
            tnNtinfoHistory.setEnergy(b); //区分氮气气调还是氮气房
            tnNtinfoHistory.setEndtime(new Date()); // 结束时间
            tNNtinfoHistoryMapper.updateByExampleSelective(tnNtinfoHistory,example); // 更新作业记录
            nitrogenService.save(ktinfoJson); // 更新操作状态
        }
    }

    @Transactional
    @Override
    public String synchronizationAll(String orgId) {
        //获取所有基础数据getNitrogenData
        String device = SendEntity.cxfFactor().getNitrogenData();
        //转换对象
        BasicEntity basicEntity = (BasicEntity) JsonToObjectUtils.jsonToObject(device, BasicEntity.class);
        if (basicEntity.getState().equals("0")) {
            List<Object> data = basicEntity.getData();
            if (data.size() > 0) {
                String tt = JSONObject.toJSONString(data);
                ArrayList<Object> objects = JsonToObjectUtils.jsonToObjectsDiverse(tt, TNRoomInfo.class,"yyyy-MM-dd'T'HH:mm:ss");
                objects.forEach(t -> {
                    TNRoomInfo tc = (TNRoomInfo) t;
                    tc.setId(uUidUtils.getCodeId(orgId, "t_n_room_info"));
                    tc.setOrgId(orgId);
                    tc.setDelFlag(1); //未删除sitecode
                    String vdevcode = tc.getSitecode();
                    TNRoomInfo info1 = getVinfo(vdevcode);
                    if (info1 != null) {
                        tc.setId(info1.getId());
                        tnRoomInfoMapper.updateByPrimaryKey(tc);
                    } else {
                        tnRoomInfoMapper.insert(tc);
                    }
                });
            }
        } else {
            return basicEntity.getMsg();
        }
        return basicEntity.getMsg();
    }

    public TNRoomInfo getVinfo(String vdevcode) {
        TNRoomInfoExample example = new TNRoomInfoExample();
        TNRoomInfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(vdevcode)) {
            criteria.andSitecodeEqualTo(vdevcode);
        }
        List<TNRoomInfo> infos = tnRoomInfoMapper.selectByExample(example);
        if (infos.size() > 0) {
            return infos.get(0);
        }
        return null;
    }
}
